package com.shenghua.config;

import com.shenghua.enums.AuthEnum;
import com.shenghua.enums.CommEnum;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.web.bind.annotation.RequestMethod;
import springfox.documentation.builders.ApiInfoBuilder;
import springfox.documentation.builders.PathSelectors;
import springfox.documentation.builders.RequestHandlerSelectors;
import springfox.documentation.builders.ResponseMessageBuilder;
import springfox.documentation.service.Contact;
import springfox.documentation.service.ResponseMessage;
import springfox.documentation.spi.DocumentationType;
import springfox.documentation.spring.web.plugins.Docket;
import springfox.documentation.swagger2.annotations.EnableSwagger2;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;

@Configuration
@EnableSwagger2
public class SwaggerConfig {

    @Value("http:localhost:${server.port:8081}")
    private String url;

    @Bean
    public Docket docketCommon() {
        System.out.println("SwaggerConfig is loaded.");
        List<ResponseMessage> responseMessageList = new ArrayList<>();
        Arrays.stream(CommEnum.values()).forEach(enums -> {
            responseMessageList.add(
                    new ResponseMessageBuilder().code(enums.getCode()).message(enums.getMessage()).build()
            );
        });
        Arrays.stream(AuthEnum.values()).forEach(enums -> {
            responseMessageList.add(
                    new ResponseMessageBuilder().code(enums.getCode()).message(enums.getMessage()).build()
            );
        });
        return new Docket(DocumentationType.SWAGGER_2)
                .globalResponseMessage(RequestMethod.GET, responseMessageList)
                .globalResponseMessage(RequestMethod.POST, responseMessageList)
                .globalResponseMessage(RequestMethod.PUT, responseMessageList)
                .globalResponseMessage(RequestMethod.DELETE, responseMessageList)
                .groupName("shenghua").select()
                .apis(RequestHandlerSelectors.basePackage("com.shenghua.controller"))
                .paths(PathSelectors.any())
                .build()
                .apiInfo(new ApiInfoBuilder().
                        title("shenghua Restful API").
                        description("接口API").
                        contact(new Contact("", "", "")).termsOfServiceUrl(url).
                        version("1.0").
                        build());
    }

}