package com.shenghua.controller;

import com.shenghua.dto.CaseArticleDTO;
import com.shenghua.entitys.CaseArticle;
import com.shenghua.entitys.CaseArticleCategory;
import com.shenghua.entitys.Page;
import com.shenghua.entitys.Result;
import com.shenghua.service.CaseArticleService;
import com.shenghua.vo.CaseArticleVO;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;

@RestController
@RequestMapping("/case")
@Api(tags = "案例中心")
public class CaseController {



    @Autowired
    private CaseArticleService caseArticleService;

    @PostMapping("/queryPage" )
    @ApiOperation(value = "分页查询案例列表")
    public Result<Page<List<CaseArticle>>> queryPage(@RequestBody CaseArticleDTO dto){
        Page<List<CaseArticle>> listPage = caseArticleService.queryPage(dto);
        return Result.success(listPage);
    }


    @GetMapping("/getCategory" )
    @ApiOperation(value = "案例分类")
    public Result<Page<List<CaseArticle>>> getCategory(){
        List<CaseArticleCategory> listCategory = caseArticleService.getCategory();
        return Result.success(listCategory);
    }

    @PostMapping("/save" )
    @ApiOperation(value = "新增案例文章")
    public Result save(@RequestBody CaseArticle  category){
        boolean save = caseArticleService.save(category);
        if (!save){
            return Result.fail();
        }
        return Result.success();
    }

    @GetMapping("/getAll" )
    @ApiOperation(value = "全部案例文章")
    public Result<List<CaseArticleVO>> getAll(){
        return Result.success(caseArticleService.getAll());
    }

    @GetMapping("/getDetail")
    @ApiImplicitParam(value = "ID", name = "id", paramType = "query", required = true)
    @ApiOperation(value = "按新闻ID查询新闻详情")
    public Result<CaseArticleVO> getNewsById(Integer id){
        return Result.success(caseArticleService.getNewsById(id));
    }
}
